import 'package:flutter/material.dart';
import 'package:vdocipher_flutter/src/views/vdo_player_with_controller.dart';
import 'package:vdocipher_flutter/vdocipher_flutter.dart';
import 'package:wakelock/wakelock.dart';

/// Widget for displaying video from your VdoCipher dashboard along with basic
/// video UI controls.
///
/// On being created, this widget creates a native platform video player and
/// provides a [VdoPlayerController] to control playback. The
/// [VdoPlayerController] reference is returned in the [onPlayerCreated] function
/// provided as an argument in the constructor.
class VdoPlayer extends StatefulWidget {
  final EmbedInfo embedInfo;
  final Function(VdoPlayerController) onPlayerCreated;
  final Function(bool) onFullscreenChange;

  const VdoPlayer(
      {Key key, @required this.embedInfo, @required this.onPlayerCreated,
        this.onFullscreenChange})
      : super(key: key);

  @override
  _VdoPlayerState createState() => _VdoPlayerState();
}

class _VdoPlayerState extends State<VdoPlayer> {
  VdoPlayerController _controller;
  bool _isFullScreen = false;

  @override
  void dispose() {
    Wakelock.disable();
    super.dispose();
  }

  _getPlayerWithControls() {
    return PlayerWithController(
        embedInfo: widget.embedInfo,
        onPlayerCreated: (controller) => _onPlayerCreated(controller),
        onFullscreenChange: _onFullscreenChange);
  }

  @override
  Widget build(BuildContext context) {
    return SafeArea(
        top: !_isFullScreen,
        left: !_isFullScreen,
        bottom: !_isFullScreen,
        right: !_isFullScreen,
        child: _getPlayerWithControls()
      );
  }

  _onPlayerCreated(VdoPlayerController controller) {
    _controller = controller;
    _controller.load(widget.embedInfo);

    _controller.addListener(() {
      if (_controller.isLoading ??
          _controller.isBuffering ??
          _controller.isPlaying) {
        Wakelock.enable(); // Keep screen ON if video loading, buffering or playing
      }

      if (_controller.isEnded) {
        Wakelock.disable(); // Disable wakelock if video is ended
      }
    });

    widget?.onPlayerCreated(_controller);
  }

  _onFullscreenChange(isFullscreen) {
    setState(() {
      _isFullScreen = isFullscreen;
    });

    if (widget.onFullscreenChange != null) {
      widget.onFullscreenChange(_isFullScreen);
    }
  }
}
