import 'package:flutter/cupertino.dart';
import 'package:vdocipher_flutter/vdocipher_flutter.dart';

/// VdoPlayer with Video and Controller implementation. The [VdoPlayerController] to control playback, [EmbedInfo] use to set video playback config and returns [onFullscreenChange] callback function
class PlayerWithController extends StatefulWidget {
  final Function(VdoPlayerController controller) onPlayerCreated;
  final Function(bool) onFullscreenChange;
  final EmbedInfo embedInfo;
  static const double aspectRatio = 16/9;

  PlayerWithController(
      {Key key, @required this.embedInfo, this.onPlayerCreated,
        this.onFullscreenChange})
      : super(key: key);

  @override
  _PlayerWithControllerState createState() => _PlayerWithControllerState();
}

class _PlayerWithControllerState extends State<PlayerWithController> {
  VdoPlayerController _controller;
  VdoPlatformView _vdoPlayerView;

  _getVdoPlayerViewWidget() {
    if (_vdoPlayerView == null) {
      _vdoPlayerView = VdoPlatformView(
          key: UniqueKey(),
          onPlayerCreated: (controller) => _onPlayerCreated(controller));
    }

    return _vdoPlayerView;
  }

  _onFullscreenChange(isFullscreen) {
    if (widget.onFullscreenChange != null) {
      widget.onFullscreenChange(isFullscreen);
    }
  }

  Stack _buildPlayerWithControls(VdoPlayerController vdoController,
      BuildContext context, Size screenSize) {
    return Stack(
      children: <Widget>[
        Positioned.fill(
          child: _getVdoPlayerViewWidget(),
        ),
        _controller == null
            ? SizedBox.shrink()
            : VdoControllerView(
                controller: _controller,
                onFullscreenChange: _onFullscreenChange
              )
      ],
    );
  }

  @override
  Widget build(BuildContext context) {
    Size screenSize = MediaQuery.of(context).size;

    return Center(
      child: SizedBox(
        height: screenSize.height,
        width: screenSize.width,
        child: AspectRatio(
          aspectRatio: PlayerWithController.aspectRatio,
          child: _buildPlayerWithControls(_controller, context, screenSize),
        ),
      ),
    );
  }

  _onPlayerCreated(VdoPlayerController controller) {
    setState(() {
      _controller = controller;
    });

    widget?.onPlayerCreated(controller);
    controller.load(widget.embedInfo);
  }
}
